@@ -11,6 +11,7 @@
 import email
 import itertools
 import os
+import pathlib
 import re
 import shutil
 import tempfile
@@ -19,6 +20,8 @@ from collections import defaultdict
 from typing import List
 from typing import NamedTuple
 from urllib.parse import quote_plus
+from urllib.parse import urlparse
+from urllib.parse import urlunparse
 
 import attr
 import packageurl
@@ -26,9 +29,9 @@ import requests
 from bs4 import BeautifulSoup
 from commoncode import fileutils
 from commoncode.hash import multi_checksums
-from packaging import tags as packaging_tags
-from packaging import version as packaging_version
-from packaging.specifiers import SpecifierSet
+from packvers import tags as packaging_tags
+from packvers import version as packaging_version
+from packvers.specifiers import SpecifierSet
 
 from python_inspector import DEFAULT_PYTHON_VERSION
 from python_inspector import utils_pip_compatibility_tags
@@ -174,7 +177,16 @@ PLATFORMS_BY_OS = {
     ],
 }
 
-CACHE_THIRDPARTY_DIR = ".cache/thirdparty"
+CACHE_THIRDPARTY_DIR = os.environ.get("PYTHON_INSPECTOR_CACHE_DIR")
+if not CACHE_THIRDPARTY_DIR:
+    CACHE_THIRDPARTY_DIR = ".cache/python_inspector"
+    try:
+        os.makedirs(CACHE_THIRDPARTY_DIR, exist_ok=True)
+    except Exception:
+        home = pathlib.Path.home()
+        CACHE_THIRDPARTY_DIR = str(home / ".cache/python_inspector")
+        os.makedirs(CACHE_THIRDPARTY_DIR, exist_ok=True)
+
 
 ################################################################################
 
@@ -939,7 +951,6 @@ def get_sdist_name_ver_ext(filename):
 
 @attr.attributes
 class Sdist(Distribution):
-
     extension = attr.ib(
         repr=False,
         type=str,
@@ -1585,11 +1596,37 @@ class PypiSimpleRepository:
             url, _, _sha256 = anchor_tag["href"].partition("#sha256=")
             if "data-requires-python" in anchor_tag.attrs:
                 python_requires = anchor_tag.attrs["data-requires-python"]
+            # Resolve relative URL
+            url = resolve_relative_url(package_url, url)
             links.append(Link(url=url, python_requires=python_requires))
         # TODO: keep sha256
         return links
 
 
+def resolve_relative_url(package_url, url):
+    """
+    Return the resolved `url` URLstring given a `package_url` base URL string
+    of a package.
+
+    For example:
+    >>> resolve_relative_url("https://example.com/package", "../path/file.txt")
+    'https://example.com/path/file.txt'
+    """
+    if not url.startswith(("http://", "https://")):
+        base_url_parts = urlparse(package_url)
+        url_parts = urlparse(url)
+        # If the relative URL starts with '..', remove the last directory from the base URL
+        if url_parts.path.startswith(".."):
+            path = base_url_parts.path.rstrip("/").rsplit("/", 1)[0] + url_parts.path[2:]
+        else:
+            path = urlunparse(
+                ("", "", url_parts.path, url_parts.params, url_parts.query, url_parts.fragment)
+            )
+        resolved_url_parts = base_url_parts._replace(path=path)
+        url = urlunparse(resolved_url_parts)
+    return url
+
+
 PYPI_PUBLIC_REPO = PypiSimpleRepository(index_url=PYPI_SIMPLE_URL)
 DEFAULT_PYPI_REPOS = (PYPI_PUBLIC_REPO,)
 DEFAULT_PYPI_REPOS_BY_URL = {r.index_url: r for r in DEFAULT_PYPI_REPOS}
